==> zio-aws-lexmodelsv2_2.12-5.17.104.4-sources.jar: zio/aws/lexmodelsv2/model/UpdateBotRequest.scala <==
package zio.aws.lexmodelsv2.model
import java.lang.Integer
import zio.aws.lexmodelsv2.model.primitives.{
  RoleArn,
  SessionTTL,
  Description,
  Name,
  Id
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateBotRequest(
    botId: Id,
    botName: Name,
    description: Option[Description] = None,
    roleArn: RoleArn,
    dataPrivacy: zio.aws.lexmodelsv2.model.DataPrivacy,
    idleSessionTTLInSeconds: SessionTTL
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest = {
    import UpdateBotRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
      .builder()
      .botId(Id.unwrap(botId): java.lang.String)
      .botName(Name.unwrap(botName): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .dataPrivacy(dataPrivacy.buildAwsValue())
      .idleSessionTTLInSeconds(
        SessionTTL.unwrap(idleSessionTTLInSeconds): Integer
      )
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.UpdateBotRequest.ReadOnly =
    zio.aws.lexmodelsv2.model.UpdateBotRequest.wrap(buildAwsValue())
}
object UpdateBotRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.UpdateBotRequest =
      zio.aws.lexmodelsv2.model.UpdateBotRequest(
        botId,
        botName,
        description.map(value => value),
        roleArn,
        dataPrivacy.asEditable,
        idleSessionTTLInSeconds
      )
    def botId: Id
    def botName: Name
    def description: Option[Description]
    def roleArn: RoleArn
    def dataPrivacy: zio.aws.lexmodelsv2.model.DataPrivacy.ReadOnly
    def idleSessionTTLInSeconds: SessionTTL
    def getBotId: ZIO[Any, Nothing, Id] = ZIO.succeed(botId)
    def getBotName: ZIO[Any, Nothing, Name] = ZIO.succeed(botName)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getDataPrivacy
        : ZIO[Any, Nothing, zio.aws.lexmodelsv2.model.DataPrivacy.ReadOnly] =
      ZIO.succeed(dataPrivacy)
    def getIdleSessionTTLInSeconds: ZIO[Any, Nothing, SessionTTL] =
      ZIO.succeed(idleSessionTTLInSeconds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
  ) extends zio.aws.lexmodelsv2.model.UpdateBotRequest.ReadOnly {
    override val botId: Id =
      zio.aws.lexmodelsv2.model.primitives.Id(impl.botId())
    override val botName: Name =
      zio.aws.lexmodelsv2.model.primitives.Name(impl.botName())
    override val description: Option[Description] = scala
      .Option(impl.description())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Description(value))
    override val roleArn: RoleArn =
      zio.aws.lexmodelsv2.model.primitives.RoleArn(impl.roleArn())
    override val dataPrivacy: zio.aws.lexmodelsv2.model.DataPrivacy.ReadOnly =
      zio.aws.lexmodelsv2.model.DataPrivacy.wrap(impl.dataPrivacy())
    override val idleSessionTTLInSeconds: SessionTTL =
      zio.aws.lexmodelsv2.model.primitives
        .SessionTTL(impl.idleSessionTTLInSeconds())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
  ): zio.aws.lexmodelsv2.model.UpdateBotRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lexmodelsv2_2.12-5.17.271.1-sources.jar: zio/aws/lexmodelsv2/model/UpdateBotRequest.scala <==
package zio.aws.lexmodelsv2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lexmodelsv2.model.primitives.{
  RoleArn,
  SessionTTL,
  Description,
  Name,
  Id
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class UpdateBotRequest(
    botId: Id,
    botName: Name,
    description: Optional[Description] = Optional.Absent,
    roleArn: RoleArn,
    dataPrivacy: zio.aws.lexmodelsv2.model.DataPrivacy,
    idleSessionTTLInSeconds: SessionTTL
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest = {
    import UpdateBotRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
      .builder()
      .botId(Id.unwrap(botId): java.lang.String)
      .botName(Name.unwrap(botName): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .dataPrivacy(dataPrivacy.buildAwsValue())
      .idleSessionTTLInSeconds(
        SessionTTL.unwrap(idleSessionTTLInSeconds): Integer
      )
      .build()
  }
  def asReadOnly: zio.aws.lexmodelsv2.model.UpdateBotRequest.ReadOnly =
    zio.aws.lexmodelsv2.model.UpdateBotRequest.wrap(buildAwsValue())
}
object UpdateBotRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.UpdateBotRequest =
      zio.aws.lexmodelsv2.model.UpdateBotRequest(
        botId,
        botName,
        description.map(value => value),
        roleArn,
        dataPrivacy.asEditable,
        idleSessionTTLInSeconds
      )
    def botId: Id
    def botName: Name
    def description: Optional[Description]
    def roleArn: RoleArn
    def dataPrivacy: zio.aws.lexmodelsv2.model.DataPrivacy.ReadOnly
    def idleSessionTTLInSeconds: SessionTTL
    def getBotId: ZIO[Any, Nothing, Id] = ZIO.succeed(botId)
    def getBotName: ZIO[Any, Nothing, Name] = ZIO.succeed(botName)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getDataPrivacy
        : ZIO[Any, Nothing, zio.aws.lexmodelsv2.model.DataPrivacy.ReadOnly] =
      ZIO.succeed(dataPrivacy)
    def getIdleSessionTTLInSeconds: ZIO[Any, Nothing, SessionTTL] =
      ZIO.succeed(idleSessionTTLInSeconds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
  ) extends zio.aws.lexmodelsv2.model.UpdateBotRequest.ReadOnly {
    override val botId: Id =
      zio.aws.lexmodelsv2.model.primitives.Id(impl.botId())
    override val botName: Name =
      zio.aws.lexmodelsv2.model.primitives.Name(impl.botName())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Description(value))
    override val roleArn: RoleArn =
      zio.aws.lexmodelsv2.model.primitives.RoleArn(impl.roleArn())
    override val dataPrivacy: zio.aws.lexmodelsv2.model.DataPrivacy.ReadOnly =
      zio.aws.lexmodelsv2.model.DataPrivacy.wrap(impl.dataPrivacy())
    override val idleSessionTTLInSeconds: SessionTTL =
      zio.aws.lexmodelsv2.model.primitives
        .SessionTTL(impl.idleSessionTTLInSeconds())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.UpdateBotRequest
  ): zio.aws.lexmodelsv2.model.UpdateBotRequest.ReadOnly = new Wrapper(impl)
}
